Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(185)

Unified Diff: base/test/android/javatests/src/org/chromium/base/test/util/FlakyTest.java

Issue 1856203003: Add message as element for DisabledTest and FlakyTest to list crbug link (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/test/android/javatests/src/org/chromium/base/test/util/DisabledTest.java ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/test/android/javatests/src/org/chromium/base/test/util/FlakyTest.java
diff --git a/base/test/android/javatests/src/org/chromium/base/test/util/DisabledTest.java b/base/test/android/javatests/src/org/chromium/base/test/util/FlakyTest.java
similarity index 76%
copy from base/test/android/javatests/src/org/chromium/base/test/util/DisabledTest.java
copy to base/test/android/javatests/src/org/chromium/base/test/util/FlakyTest.java
index 58bdb8a6af755a050d69e799ca966a7c6efbf983..83f8e9f43d3386dbb6457ac578e0dbf8427a6498 100644
--- a/base/test/android/javatests/src/org/chromium/base/test/util/DisabledTest.java
+++ b/base/test/android/javatests/src/org/chromium/base/test/util/FlakyTest.java
@@ -1,4 +1,4 @@
-// Copyright 2012 The Chromium Authors. All rights reserved.
+// Copyright 2016 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
@@ -10,12 +10,13 @@ import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
/**
* This annotation is for disabled tests.
* <p>
* Tests with this annotation will not be run on any of the normal bots.
* Please note that they might eventually run on a special bot.
*/
@Target({ElementType.METHOD, ElementType.TYPE})
@Retention(RetentionPolicy.RUNTIME)
-public @interface DisabledTest {
+public @interface FlakyTest {
+ String message() default "";
}
« no previous file with comments | « base/test/android/javatests/src/org/chromium/base/test/util/DisabledTest.java ('k') | no next file » | no next file with comments »
@@ -10,12 +10,13 @@ import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;
/**
- * This annotation is for disabled tests.
+ * This annotation is for flaky tests.
* <p>
* Tests with this annotation will not be run on any of the normal bots.

Powered by Google App Engine
This is Rietveld 408576698